#!/bin/bash
#
# check_sensors is part of the project WIFI Plant
# The script is used to check the temperature and humididty every 30 seconds
# Probado en Raspibian y Raspberry Pi
# Authors:  Pedro Cadavid 
# Date: 15/11/2016
# License: GPLv3
#

# We use Bash_GPIO.sh to transform string in Morse to light using GPIO
source Bash_GPIO.sh

# We use Bash_Morse.sh to work with leds
source Bash_Morse.sh

# We se lcd_rgb.sh to display messages on the screen
source lcd_rgb.sh

# We use calendar.sh to check timetable
source calendar.sh

# Creamos las variables que vamos a usar con MySQL
sql_host="localhost"
sql_usuario="uoc"
sql_password="Password"

alertas=0 # Variable para controlar el número de parámetros incorrecto acorde a la especie
greater="" # True o false si el A > B

isnum()
#checks if a $1 input value is numeric.
# Usage isnum 4
# If is number the function will return 1
{
    awk -v a="$1" 'BEGIN {print (a == a + 0)}';
}


is_greater()
#checks if a $1 input value is greater than $2
# Usage is_greater $1 $2
# If is $1 is greater than $2 will return 1
{
    local result
    result=$( echo "$1>$2" | bc )

    if [[ "$result" == "1" ]]; then
        greater=true
    else
        greater=false
    fi
}


play_audio()
#plays an audio file if global var audio is set to true
{
    local date

    check_festivo
    is_night
    if [[ "$festivo" == true || $night == true ]]; then
	return 1
    fi
	
    if [[ "$audio" == "1" ]];then  #El audio está activo

        play $1>>/dev/null 2>&1

        date=`date "+%Y/%m/%d %H:%M:%S"`
        mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;INSERT INTO log_msj_hablados(fichero,fecha)VALUES ('$1', '$date');"

    fi
}


# Función para leer la temperatura y humedad y almacenarla en la BBDD cada 60 segundos
check_sensors()
{

    local fecha
    local id_pl
    local planta_monitorizada
    local temperatura
    local humedad
    local lux
    local humedad_suelo
    local calidad_aire
    local temp_max
    local temp_min
    local humedad_max
    local humedad_min
    local lux_max
    local lux_min
    local humedad_suelo_max
    local humedad_suelo_min
    local calidad_aire_max
    local calidad_aire_min
    local msg_temp
    local msg_humedad
    local msg_lux
    local msg_humedad_suelo
    local msg_log
    local temp1
    local temp2
    local temp3
    local temp4
    local temp5
    local sensors_read_interval
    local idioma
    local ip=`ip addr show eth0 | grep -v inet6 | grep 'inet' | sed 's/^[ \t]*//' | cut -f2 -d" " | cut -f1 -d"/"`

    set audio
    set greater

    # Creamos un bucle infinito
    while true;
    do
        alertas=0
        temp1=0
        temp2=0
        temp3=0
        temp4=0

        sensors_read_interval=`mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;select  sensors_read_interval from configuracion;" | grep -v sensors_read_interval`
        sensors_read_interval=`expr $sensors_read_interval + 0`
        audio=`mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;select audio from configuracion;" | grep -v audio`
        idioma=`mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;select idioma from configuracion;" | grep -v idioma`
        idioma=`expr $idioma + 0`

           case "$idioma" in
            0)  #python switch_led3_on.py
                python switch_led1_off.py
                python switch_led2_off.py
                for i in $(seq 1 1 9)
                do
                  lcd_set_color "red"
                  sleep 0.3
                  lcd_set_color "yellow"
                  sleep 0.3
                  lcd_set_color "red"
                done
                tengo_calor="audio/calor.wav"
                tengo_frio="audio/frio.wav"
                deshidratando="audio/deshidratando.wav"
                pulverizame="audio/pulverizame.wav"
                demasiada_luz="audio/demasiada_luz.wav"
                poca_luz="audio/poca_luz.wav"
                raices_encharcadas="audio/raices_encharcadas.wav"
                por_que_no_me_riegas="/root/WIFIPlant/audio/por_que_no_riegas.wav"
                ;;
            1)  #python switch_led2_on.py
                python switch_led1_off.py
                python switch_led3_off.py
                for i in $(seq 1 1 9)
                do
                  lcd_set_color "green"
                  sleep 0.3
                  lcd_set_color "red"
                  sleep 0.3
                  lcd_set_color "green"
                done
                tengo_calor="audio/Beroa.wav"
                tengo_frio="audio/Hotza.wav"
                deshidratando="audio/Deshidratatzen.wav"
                pulverizame="audio/Ureztatu.wav"
                demasiada_luz="audio/Betaurrekoak.wav"
                poca_luz="audio/Argi_gutxi.wav"
                raices_encharcadas="audio/Sustraiak.wav"
                por_que_no_me_riegas="/root/WIFIPlant/audio/Zergaitik.wav"
                ;;
            2)  #python switch_led1_on.py
                python switch_led2_off.py
                python switch_led3_off.py
                for i in $(seq 1 1 9)
                do
                  lcd_set_color "blue"
                  sleep 0.3
                  lcd_set_color "red"
                  sleep 0.3
                  lcd_set_color "blue"
                done
                tengo_calor="audio/hot.wav"
                tengo_frio="audio/cold.wav"
                deshidratando="audio/dehydrating.wav"
                pulverizame="audio/pulverize.wav"
                demasiada_luz="audio/many_light.wav"
                poca_luz="audio/few_light.wav"
                raices_encharcadas="audio/flooded_roots.wav"
                por_que_no_me_riegas="/root/WIFIPlant/audio/water_me.wav"
                ;;
           esac
           
         # La planta a monitorizar será la que esté ahora activa
        id_pl=`mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;select id_pl from plantas where activa=0;" | grep -v id_pl`
        planta_monitorizada=`mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;select nombre_cie from plantas where activa=0;" | grep -v nombre_cie`



        while [[ "$temp1" -ne 1 || "$temperatura" == "nan" || "$temperatura" == "65535" ]];
        do
           temperatura=$(python temp_hum.py | awk '{print $1}')>>/dev/null 2>&1
           temp1=`isnum $temperatura`
        done
        temperatura=`echo $temperatura/1 | bc`


        while [[ "$temp2" -ne 1 || "$humedad" == "nan" || "$humedad" == "65535" ]];
        do
           humedad=$(python temp_hum.py | awk '{print $2}')>>/dev/null 2>&1
           temp2=`isnum $humedad`
        done
        humedad=`echo $humedad/1 | bc`

        while [[ "$temp3" -ne 1 || "$lux" == "nan" || "$lux" -gt 10000 ]];
        do
               lux=$(python light.py | awk '{print $1}')>>/dev/null 2>&1
               temp3=`isnum $lux`
        done
        lux=`echo $lux | bc`

        while [[ "$temp4" -ne 1 || "$humedad_suelo" == "nan" || "$humedad_suelo" -gt 10000 ]];
        do
           humedad_suelo=$(python moisture.py | tail -1)>>/dev/null 2>&1
           temp4=`isnum $humedad_suelo`
        done
        #humedad_suelo=`echo $humedad_suelo*0.1 | bc -l`
        humedad_suelo=`echo $humedad_suelo/10 | bc`

        while [[ "$temp5" -ne 1 || "$calidad_aire" == "nan" || "$calidad_aire" -gt 10000 ]];
        do
           calidad_aire=$(python air_quality.py | tail -1)>>/dev/null 2>&1
           temp5=`isnum $calidad_aire`
        done
        calidad_aire=`echo $calidad_aire/1 | bc`

        #echo "La temp es $temperatura, la humedad es $humedad, la luz es $lux y la humedad suelo es $humedad_suelo"
        fecha=`date "+%Y/%m/%d %H:%M:%S"`
        mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;INSERT INTO planta_temperatura(id_ma, id_pl,temperatura,fecha)VALUES (1,'$id_pl', '$temperatura', '$fecha');"
        mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;INSERT INTO planta_humedad(id_ma, id_pl,humedad,fecha)VALUES (1,'$id_pl', '$humedad', '$fecha');"
        mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;INSERT INTO planta_lux(id_ma, id_pl,lux,fecha)VALUES (1,'$id_pl', '$lux', '$fecha');"
        mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;INSERT INTO planta_humedad_suelo(id_ma, id_pl,humedad_suelo,fecha)VALUES (1,'$id_pl', '$humedad_suelo', '$fecha');"
        mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;INSERT INTO planta_calidad_aire(id_ma, id_pl,calidad,fecha)VALUES (1,'$id_pl', '$calidad_aire', '$fecha');"
        lcd_write_text "   WIFIPlant    " "1"
        lcd_write_text "$fecha" "2"
        sleep 3
        lcd_write_text "                " "2"
        lcd_write_text "$ip" "2"
        sleep 3

        # Obtebemos los valores max y min tolerados por la especie de planta
        humedad_max=`mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;select max_hum from humedad where id_pl='$id_pl';" | grep -v max_hum`
        humedad_min=`mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;select min_hum from humedad where id_pl='$id_pl';" | grep -v min_hum`
        temp_max=`mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;select temp_max from temperatura where id_pl='$id_pl';" | grep -v temp_max`
        temp_min=`mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;select temp_min from temperatura where id_pl='$id_pl';" | grep -v temp_min`
        lux_max=`mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;select max_lux from lux where id_pl='$id_pl';" | grep -v max_lux`
        lux_min=`mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;select min_lux from lux where id_pl='$id_pl';" | grep -v min_lux`
        calidad_aire_max=`mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;select max_cal from calidad_aire where id_pl='$id_pl';"| grep -v max_cal`
        calidad_aire_min=`mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;select min_cal from calidad_aire where id_pl='$id_pl';"| grep -v min_cal`
        humedad_suelo_max=`mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;select max_hum_sue from humedad_suelo where id_pl='$id_pl';" | grep -v max_hum_sue`
        humedad_suelo_min=`mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;select min_hum_sue from humedad_suelo where id_pl='$id_pl';" | grep -v min_hum_sue`
        #echo "Valores límite hume_max $humedad_max; hume_min $humedad_min; temp_max $temp_max;temp_min $temp_min;lux_max $lux_max;lux_min $lux_min;humedad_suelo_max $humedad_suelo_max;humedad_suelo_min $humedad_suelo_min"

        #temperatura=`expr $temperatura + 0`
        #humedad=`expr $humedad + 0`
        humedad_max=`expr $humedad_max + 0`
        humedad_min=`expr $humedad_min + 0`
        temp_max=`expr $temp_max + 0`
        temp_min=`expr $temp_min + 0`
        lux_max=`expr $lux_max + 0`
        lux_min=`expr $lux_min + 0`
        humedad_suelo_max=`expr $humedad_suelo_max + 0`
        humedad_suelo_min=`expr $humedad_suelo_min + 0`
        calidad_aire_max=`expr $calidad_aire_max + 0`
        calidad_aire_min=`expr $calidad_aire_min + 0`

        #echo "Los datos son $humedad_max $humedad_min $temp_max $temp_min $temperatura $humedad"

        # Comprobamos los parámetros en función de la especie
        is_greater $temperatura $temp_max
        if [[ "$greater" == true ]]; then
            alertas=`expr $alertas + 2`
           # echo "Temperatura superior a $temp_max"
            msg_temp="Tengo calor"
            msg_log="Temperatura de $temperatura ºC (límite de $temp_max para la planta $planta_monitorizada)"
            mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;INSERT INTO alertas(id_ma, id_pl,mensaje,fecha)VALUES (1,'$id_pl', '$msg_log', '$fecha');"
            cp /var/www/html/wifiplant/fotos/Calor.gif /var/www/html/wifiplant/fotos/mensaje.gif
            #play_audio audio/calor.wav
            play_audio $tengo_calor
            lcd_write_text "Tengo calor      " "1"
            sleep 2
             # bt_send_file calor2.wav
        fi

        is_greater $temperatura $temp_min
        if [[ "$greater" == false ]]; then
            alertas=`expr $alertas + 2`
           # echo "Temperatura inferior a $temp_min"
            msg_temp="Tengo frío"
            msg_log="Temperatura de $temperatura ºC (límite de $temp_min para la planta $planta_monitorizada)"
            mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;INSERT INTO alertas(id_ma, id_pl,mensaje,fecha)VALUES (1,'$id_pl', '$msg_log', '$fecha');"
            cp /var/www/html/wifiplant/fotos/Frio.gif /var/www/html/wifiplant/fotos/mensaje.gif
            #play_audio audio/frio.wav
            play_audio $tengo_frio
            lcd_write_text "Tengo frio      " "1"
            sleep 2
              # bt_send_file frio.wav
        fi

        is_greater $humedad $humedad_max
        if [[ "$greater" == true ]]; then
            alertas=`expr $alertas + 1`
           # echo "Humedad superior a $humedad_max"
            msg_humedad="Chorreo agua"
            msg_log="Humedad de $humedad % (límite de $humedad_max para la planta $planta_monitorizada)"
            mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;INSERT INTO alertas(id_ma, id_pl,mensaje,fecha)VALUES (1,'$id_pl', '$msg_log', '$fecha');"
            cp /var/www/html/wifiplant/fotos/Mucha_humedad.gif /var/www/html/wifiplant/fotos/mensaje.gif
            #play_audio audio/deshidratando.wav
            play_audio $deshidratando
            lcd_write_text "Demasiada         " "1"
            lcd_write_text "humedad           " "2"
            sleep 2
            # bt_send_file mojada.wav
        fi

        is_greater $humedad $humedad_min
        if [[ "$greater" == false ]]; then
            alertas=`expr $alertas + 1`
           # echo "Humedad inferior a $humedad_min"
            msg_humedad="Me reseco"
            msg_log="Humedad de $humedad % (límite de $humedad_min para la planta $planta_monitorizada)"
            mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;INSERT INTO alertas(id_ma, id_pl,mensaje,fecha)VALUES (1,'$id_pl', '$msg_log', '$fecha');"
            cp /var/www/html/wifiplant/fotos/Poca_humedad.gif /var/www/html/wifiplant/fotos/mensaje.gif
            #play_audio audio/pulverizame.wav
            play_audio $pulverizame 
            lcd_write_text "Ambiente" "1"
            lcd_write_text "reseco         " "2"
            sleep 2
        fi

        is_night
        if [[ $night == false  ]];then
        is_greater $lux $lux_max
        if [[ "$greater" == true ]]; then
            alertas=`expr $alertas + 1`
           # echo "Iluminación superior a $lux_max"
            msg_humedad="Voy a necesitar crema solar"
            msg_log="Iluminación de $lux  (límite de $lux_max para la planta $planta_monitorizada)"
            mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;INSERT INTO alertas(id_ma, id_pl,mensaje,fecha)VALUES (1,'$id_pl', '$msg_log', '$fecha');"
            #play_audio audio/demasiada_luz.wav
            play_audio $demasiada_luz
            cp /var/www/html/wifiplant/fotos/Demasiada_luz.gif /var/www/html/wifiplant/fotos/mensaje.gif
            lcd_write_text "Demasiada        " "1"
            lcd_write_text "luz              " "2"
            sleep 2
        fi

        is_greater $lux $lux_min
        if [[ "$greater" == false ]]; then
            alertas=`expr $alertas + 1`
           # echo "Iluminación inferior a $lux_min"
            msg_humedad="¿Sabes que las plantas usamos la luz para realizar la fotosíntesis?"
            msg_log="Iluminación de $lux  (límite de $lux_min para la planta $planta_monitorizada)"
            mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;INSERT INTO alertas(id_ma, id_pl,mensaje,fecha)VALUES (1,'$id_pl', '$msg_log', '$fecha');"
            #play_audio audio/poca_luz.wav
            play_audio $poca_luz
            cp /var/www/html/wifiplant/fotos/Poca_luz.gif /var/www/html/wifiplant/fotos/mensaje.gif
            lcd_write_text "Poca luz        " "1"
            sleep 2
        fi
        else echo ""
        fi #is_night

        is_greater $humedad_suelo $humedad_suelo_max
        if [[ "$greater" == true ]]; then
            alertas=`expr $alertas + 2`
           # echo "Humedad del suelo superior a $humedad_suelo_max"
            msg_humedad="Tengo las raíces encharcadas"
            msg_log="Humedad del sustrato de $humedas_suelo  (límite de $humedad_suelo_max para la planta $planta_monitorizada)"
            mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;INSERT INTO alertas(id_ma, id_pl,mensaje,fecha)VALUES (1,'$id_pl', '$msg_log', '$fecha');"
            #play_audio audio/raices_encharcadas.wav
            play_audio $raices_encharcadas
            cp /var/www/html/wifiplant/fotos/Demasiado_riego.gif /var/www/html/wifiplant/fotos/mensaje.gif
            lcd_write_text "Raices           " "1"
            lcd_write_text "encharcadas      " "2"
            sleep 2
        fi

        is_greater $humedad_suelo $humedad_suelo_min
        if [[ "$greater" == false ]]; then
            alertas=`expr $alertas + 2`
           # echo "Humedad del sustrato inferior a humedad_suelo_min"
            msg_humedad="¿Mi sustrato es arena del desierto?"
            msg_log="Humedad del sustrato de $humedad_suelo  (límite de $humedad_suelo_min para la planta $planta_monitorizada)"
            mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;INSERT INTO alertas(id_ma, id_pl,mensaje,fecha)VALUES (1,'$id_pl', '$msg_log', '$fecha');"
            #play_audio /root/WIFIPlant/audio/por_que_no_riegas.wav
            #play_audio /root/WIFIPlant/audio/yo_tan_seca.wav
            play_audio $por_que_no_me_riegas
            cp /var/www/html/wifiplant/fotos/Falta_riego.gif /var/www/html/wifiplant/fotos/mensaje.gif
            lcd_write_text "Sustrato seco" "1"
            sleep 2
        fi

	#calidad_aire=10
	is_greater $calidad_aire $calidad_aire_max
        if [[ "$greater" == true ]]; then
            alertas=`expr $alertas + 3`
           # echo "Calidad del aire superior $calidad_aire_max"
            msg_humedad="El aire está viciado"
            msg_log="Calidad del aire de $calidad_aire  (límite de $calidad_aire_max para la planta $planta_monitorizada)"
            mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;INSERT INTO alertas(id_ma, id_pl,mensaje,fecha)VALUES (1,'$id_pl', '$msg_log', '$fecha');"
            #play_audio audio/raices_encharcadas.wav
            #cp /var/www/html/wifiplant/fotos/Demasiado_riego.gif /var/www/html/wifiplant/fotos/mensaje.gif
            lcd_write_text "Aire             " "1"
            lcd_write_text "viciado          " "2"
            sleep 2
        fi


          is_greater $calidad_aire $calidad_aire_min
        if [[ "$greater" == true ]]; then
            alertas=`expr $alertas - 1`
           # echo "Calidad aire inferior a calidad_aire_min"
            msg_humedad="Esto es aire puro"
            msg_log="Calidad del aire de $calidad_aire  (límite de $calidad_aire_min para la planta $planta_monitorizada)"
            mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;INSERT INTO alertas(id_ma, id_pl,mensaje,fecha)VALUES (1,'$id_pl', '$msg_log', '$fecha');"
            #play_audio audio/por_que_no_riegas.wav
            #play_audio audio/yo_tan_seca.wav
            #cp /var/www/html/wifiplant/fotos/Falta_riego.gif /var/www/html/wifiplant/fotos/mensaje.gif
            lcd_write_text "Aire puro" "1"
            sleep 2
        fi


        lcd_write_text "Tem:$temperatura   Hum:$humedad% " "1"
        lcd_write_text "Lux:$lux Soil:$humedad_suelo%" "2"

        sleep 2

        case "$alertas" in

        0)
           cp /var/www/html/wifiplant/fotos/feliz2.png /var/www/html/wifiplant/fotos/cara.png
           cp /var/www/html/wifiplant/fotos/Todo_OK.gif /var/www/html/wifiplant/fotos/mensaje.gif
           lcd_write_text "Todo OK           " "1"
           lcd_set_color "green"
           sleep 5
           lcd_write_text "Tem:$temperatura   Hum:$humedad% " "1"
           lcd_write_text "Lux:$lux Soil:$humedad_suelo%" "2"

           #wondershaper eth0 30000 3000
        ;;
        1)
           cp /var/www/html/wifiplant/fotos/medio2.png /var/www/html/wifiplant/fotos/cara.png
           lcd_set_color "yellow"
           #wondershaper eth0 2800 2800
        ;;
        2)
           cp /var/www/html/wifiplant/fotos/medio2b.png /var/www/html/wifiplant/fotos/cara.png
           lcd_set_color "orange"
           #wondershaper eth0 2800 2800
        ;;
        3)
           cp /var/www/html/wifiplant/fotos/triste2.png /var/www/html/wifiplant/fotos/cara.png
           cp /var/www/html/wifiplant/fotos/SOS.gif /var/www/html/wifiplant/fotos/mensaje.gif
           lcd_set_color "light-red"
           #Morse_to_Light "$msg_temp" 19
           #Morse_to_Light "$msg_humedad" 19
           #wondershaper eth0 280 280
        ;;
        #4)
        #   cp /var/www/html/wifiplant/fotos/triste2.png /var/www/html/wifiplant/fotos/cara.png
        #   cp /var/www/html/wifiplant/fotos/SOS.gif /var/www/html/wifiplant/fotos/mensaje.gif
        #   lcd_set_color "red"
        #   Morse_to_lcd "SOS"
        #;;
        *)
           cp /var/www/html/wifiplant/fotos/triste2.png /var/www/html/wifiplant/fotos/cara.png
           cp /var/www/html/wifiplant/fotos/SOS.gif /var/www/html/wifiplant/fotos/mensaje.gif
           lcd_set_color "red"
           Morse_to_lcd "SOS"
           asterisk -rx "channel originate SIP/612345678 application Playback alerta" 

        esac

        sleep $sensors_read_interval
    done
}
check_sensors&
