#!/bin/bash
#
# Bash_GPIO is part of the project WIFI Plant
# The script makes easier to access GPIO using Bash
# Probado en Raspibian y Raspberry Pi
# Author:  Pedro Cadavid
# Date: 18/10/2016
# License: GPLv3
# Guided using "RPi Low-level peripherals" article from elinux.org
# http://elinux.org/RPi_Low-level_peripherals
#

declare pin_value

gpio()
{
    local action
    local pin
    local value
    local direction
    action=$1
    pin=$2

    if [[ $action != "input" ]] && [[ $action != "output" ]] && [[ $action != "clean" ]] && [[ $action != "read_pin" ]]; then
        put_help
    fi

    # We prepare the pin we have choosen
    if [ ! -d  /sys/class/gpio/gpio$pin ]; then
        echo "$pin" > /sys/class/gpio/export
    fi

    # First if we want to use the pin to output
    if [[ $action == "output" ]]; then
        value=$3
        # We configure the selected pin to output
        if [ ! -f  /sys/class/gpio/gpio$pin/direction ]; then
            echo "out" > /sys/class/gpio/gpio$pin/direction
        else direction=`cat  /sys/class/gpio/gpio$pin/direction`
        fi

        #Check if direction is set to "out"
        if [[ $direction != "out" ]]; then
            echo "out" > /sys/class/gpio/gpio$pin/direction
        fi

        # Write output value
        echo "$value" > /sys/class/gpio/gpio$pin/value
    fi

    # If we want to use the pin to input
    if [[ $action == "input" ]]; then
        # We configure the selected pin to output
        if [ ! -f  /sys/class/gpio/gpio$pin/direction ]; then
             echo "in" > /sys/class/gpio/gpio$pin/direction
        else direction=`cat  /sys/class/gpio/gpio$pin/direction`
        fi

        #Check if direction is set to "in"
        if [[ $direction != "in" ]]; then
            echo "in" > /sys/class/gpio/gpio$pin/direction
        fi
    fi

    # Read value of the pin
     if [[ $action == "read_pin" ]]; then
        pin_value=`cat /sys/class/gpio/gpio$pin/value`
        return $pin_value
     fi

    # Finally, we can clean the vars
    if [[ $action == "clean" ]]; then
        echo $pin > /sys/class/gpio/unexport
    fi

}

put_help()
{
    echo "Error in function"
    echo "Usage:"
    echo "To read the value of pin 4: gpio read_pin 4"
    echo "To write 1 to pin 4: gpio output 4 1"
    echo "To set pin 4 to input: gpio input 4"
    echo "To clean pin 4: gpio clean 4"
    exit 0
}
