#!/bin/bash
#
# Bash_Morse is part  of the proyect WIFI Plant
# The script translate a text into Morse text and Morse to light
# Morse code is represented with text using "to_Morse" function
# Morse code is represented with light using "Morse_to_Light" function and GPIO
# Probado en Raspibian y Raspberry Pi
# Authors:Pedro Cadavid 
# Date: 01/11/2016
# License: GPLv3
#

# We use Bash_GPIO.sh to transform string in Morse to light using GPIO
source Bash_GPIO.sh

# We use lcd_rgb.sh to blink Morse messages with GrovePi rgb_lcd
source lcd_rgb.sh

#Global vars
declare string_to_convert
declare in_Morse


to_Morse()
# Function that converts an input string into its correspondient Morse string
# In the same way, it allows to output as light signal using a led
# in a Raspberry Pi.

#    Usage: It transform global vars contain of string_to_convert to in_Morse
#    to_Morse $string_to_convert

{
    local length_string
    declare -a char

    if [ $# -eq 1 ]; then
        string_to_convert=$1
    fi

    length_string=${#string_to_convert}

    for i in `seq 0 1 $length_string`;
    do
        char[$i]=`echo ${string_to_convert:$i:1}`

        case "${char[$i]}" in

            0)  char[$i]="-----"
                ;;
            1)  char[$i]=".----"
                ;;
            2)  char[$i]="..---"
                ;;
            3)  char[$i]="...--"
                ;;
            4)  char[$i]="....-"
                ;;
            5)  char[$i]="....."
                ;;
            6)  char[$i]="-...."
                ;;
            7)  char[$i]="--..."
                ;;
            8)  char[$i]="---.."
                ;;
            9)  char[$i]="----."
                ;;
            a|A|á|Á)  char[$i]=".-"
                ;;
            b|B)  char[$i]="-..."
                ;;
            c|C)  char[$i]="-.-."
                ;;
            d|D)  char[$i]="-.."
                ;;
            e|E|é|É)  char[$i]="."
                ;;
            f|F)  char[$i]="..-."
                ;;
            g|G)  char[$i]="--."
                ;;
            h|H)  char[$i]="...."
                ;;
            i|I|í|Í)  char[$i]=".."
                ;;
            j|J)  char[$i]=".---"
                ;;
            k|K)  char[$i]="-.-"
                ;;
            l|L)  char[$i]=".-.."
                ;;
            m|M)  char[$i]="--"
                ;;
            n|N)  char[$i]="-."
                ;;
            o|O|ó|Ó)  char[$i]="---"
                ;;
            p|P)  char[$i]=".--."
                ;;
            q|Q)  char[$i]="--.-"
                ;;
            r|R)  char[$i]=".-."
                ;;
            s|S)  char[$i]="..."
                ;;
            t|T)  char[$i]="-"
                ;;
            u|U|ú|Ú)  char[$i]="..-"
                ;;
            v|V)  char[$i]="...-"
                ;;
            w|W)  char[$i]=".--"
                ;;
            x|X)  char[$i]="-..-"
                ;;
            y|Y)  char[$i]="-.--"
                ;;
            z|Z)  char[$i]="--.."
                ;;
            '.')  char[$i]=".-.-.-"
                ;;
            ',')  char[$i]="--..--"
                ;;
            '?')  char[$i]="..--.."
                ;;
            '@')  char[$i]=".--.-."
                ;;
             #'"')  char[$i]=".-..-."
             #  ;;
             '')  char[$i]="/"
                ;;
        esac
        in_Morse=$in_Morse" "${char[$i]}
    done
}

swicht_off_led()
#swiches off a led using the input GPIO number
#swicht_off_led 4 swiches the led placed off pin 4
{
    local pin
    pin=$1

    gpio output $pin 0
}

swicht_on_led()
#swiches on a led using the input GPIO number
#swicht_on_led 4 swiches off the led placed on pin 4
{
    local pin
    pin=$1

    gpio output $pin 1
}


Morse_to_Light()
# Converts an input Morse string into Morse output light using a led.
# Morse_to_Light $string 4
{
    local pin

    if [ $# -lt 2 ]; then
        echo "Morse_to_Light function has 2 parameters"
        exit 0
    fi

    string_to_convert=$1
    pin=$2
    to_Morse $string_to_convert
    length_string=${#in_Morse}

    for i in `seq 0 1 $length_string`;
    do
        char[$i]=`echo ${in_Morse:$i:1}`

        case "${char[$i]}" in

            "-") swicht_on_led $pin
                 sleep 0.8
                 swicht_off_led $pin
                 sleep 0.8
                ;;
            ".") swicht_on_led $pin
                 sleep 0.2
                 swicht_off_led $pin
                 sleep 0.2
                ;;
        esac
    done
}

Morse_to_lcd()
# Converts an input Morse string into Morse output light using a Grovepi rbg_led.
# Usage: Morse_to_lcd "SOS"
{
    local pin

    if [ $# -lt 1 ]; then
        echo "Morse_to_lcd function uses 1 parameters"
        exit 0
    fi

    string_to_convert=$1
    to_Morse $string_to_convert
    length_string=${#in_Morse}

    for i in `seq 0 1 $length_string`;
    do
        char[$i]=`echo ${in_Morse:$i:1}`

        case "${char[$i]}" in

            "-") lcd_set_color "black"
                 sleep 0.8
                 lcd_set_color "red"
                 sleep 0.8
                ;;
            ".") lcd_set_color "black"
                 sleep 0.2
                 lcd_set_color "red"
                 sleep 0.2
                ;;
        esac
    done
}



