#!/bin/bash
#
# Script para gestionar un HotSpot en un servidor GNU/Linux a través
# de un servidor Radius.
# Probado en Raspibian, Debian 7 Server y Ubuntu 12.04 Server
# Autor: Pedro Cadavid
# Fecha: 29/10/2016
# Licencia: GPLv3
#


#Indicamos el archivo de confoiguración con los datos de MySQL que usará el script
#source configuracion.sh

# We use Bash_GPIO.sh to transform string in Morse to light using GPIO
source Bash_GPIO.sh

# We use Bash_Morse.sh to work with leds
source Bash_Morse.sh

# ------------ Declaramos las variables que vamos a emplear -------------
kernel=`uname -r`
distribucion=`cat /etc/issue | awk '{print $1}'`
echo $distribucion | cut -d 'n' -f 2
CPU=`cat /proc/cpuinfo |head -2|tail -1| awk '{print $4$5$6}'`
RAM_total=`free |head -2 |tail -1| awk '{print $2}'`
RAM_total=`expr $RAM_total / 1024`
RAM_ocupada=`free |head -2 |tail -1| awk '{print $3}'`
RAM_ocupada=`expr $RAM_ocupada / 1024`
disco_duro_total=`df -h | head -2 | tail -1| awk '{print $2}'`
disco_duro_ocupado=`df -h | head -2 | tail -1| awk '{print $3}'`
disco_duro_libre=`df -h | head -2 | tail -1| awk '{print $4}'`
disco_duro_porc=`df -h | head -2 | tail -1| awk '{print $5}'`
quien_soy=`whoami`
ip_int_WIFI=`ip addr show $int_WIFI | grep -v inet6 | grep 'inet' | sed 's/^[ \t]*//' | cut -f2 -d" " | cut -f1 -d"/"`
declare int_cable
declare int_WIFI
declare configuracion
declare direccion_ip
declare mascara
declare puerta_enlace
declare temperatura
declare humedad

    #Declaramos arrays y variables
    declare -a ips_conect
    declare -a macs_conect
    declare -a usuario_logueado
    declare equipos_conectados


# Creamos las variables que vamos a usar con MySQL
sql_host="localhost"
sql_usuario="root"
sql_password="Password"

# Necesitamos conocer el id de la especie de planta que se está monitorizando en estos momentos
id_pl=`mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;select id_pl from plantas where activa=0;" | grep -v id_pl`


#Variables globales empleadas en funciones
declare cadena_a_ajustar # Ajusta el tamaño de las variables


# ------------Funciones del script--------------


#Función que comprueba si el que ejecuta el script tiene permisos root
soy_root()
{
    clear
    echo -e "\e[0;36m"
    echo "";echo "";echo "";echo "";echo "";

    if [[ $quien_soy != "root" ]]; then
        echo_c "No tienes privilegios de root. Por favor, inicia el script por permisos de root"
        sleep 2
        clear
        exit 0
    fi
}

#Función que permite centrar el texto
echo_c()
{
  w=$(stty size | cut -d" " -f2)       # width of the terminal
  l=${#1}                              # length of the string
  printf "%"$((l+(w-l)/2))"s\n" "$1"  # print string padded to proper width (%Ws)
}


#Función que centra el cursor
# http://apoie.org/JulioNeves/ConversaVII.htm
centra_cursor()
{
    tput civis
    num_columnas=`tput cols`
    num_lineas=`tput lines`
    linea_central=$(((num_lineas / 2) + $1))
    columna_central=$(((num_columnas - ${#1}) / 2))
    columna_central=$((columna_central - $2))
    tput cup $linea_central $columna_central
}


#Función que comprueba si los principales servicios están instalados
is_installed()
{
    apache_instalado=false
    freeradius_instalado=false
    mysql_instalado=false
    hostapd_instalado=false
    dhcp_instalado=false

    if [ -f "/usr/sbin/apache2" ];then
       apache_instalado=true
    fi

    if [ -d "/etc/freeradius" ];then
        freeradius_instalado=true
    fi

    if [ -f "/usr/bin/mysql" ];then
        mysql_instalado=true
    fi

    if [ -f "/usr/sbin/hostapd" ];then
        hostapd_instalado=true
    fi

    if [ -d "/etc/dhcp" ];then
        dhcp_instalado=true
    fi
}

# Función que ofrece la instalación de los principales servicios. Emplea los datos obtenidos en "is_installed"
instala_servicios()
{
    is_installed

    if [ $apache_instalado == false ];then
        clear
        echo "Apache no está instalado. ¿Desea instalarlo?"
        read resp

        if [[ $resp == "S" ]] || [[ $resp == "s" ]]; then

            clear
            echo "Instalando Apache"
            while true;do echo -n .;sleep 1;done &
            apt-get install -y -q -f apache2  > /dev/null;clear
            a2enmod ssl
            mkdir -p /etc/apache2/certificados
            kill $!; trap 'kill $!' SIGTERM

            if [ $? != 0 ]; then
                clear
                echo "Instalación fallida"
                read -s
            else
                clear
                echo "Instalación correcta. Pulse una tecla"
                read -s
            fi
        fi
    fi


    if [ $mysql_instalado == false ];then
        clear
        echo "MySQL no está instalado. ¿Desea instalarlo?"
        read resp

        if [[ $resp == "S" ]] || [[ $resp == "s" ]]; then

            clear

            echo "Instalando MySQL"
            clear
            apt-get install -y -q -f mysql-server

            if [ $? != 0 ]; then
                clear
                echo "Instalación fallida"
                read -s
            else
                clear
                echo "Instalación correcta. Pulse una tecla"
                read -s
            fi
        fi
    fi

    if [ $freeradius_instalado == false ];then
        clear
        echo "Freeradius no está instalado. ¿Desea instalarlo?"
        read resp

        if [[ $resp == "S" ]] || [[ $resp == "s" ]]; then

            clear
            echo "Instalando Freeradius"
            while true;do echo -n .;sleep 1;done &
            apt-get install -y -q -f freeradius > /dev/null;clear

            if [ $? != 0 ]; then
                clear
                echo "Instalación fallida"
                read -s
            else
                clear
                echo "Instalación correcta. Pulse una tecla"
                read -s
            fi
        fi
    fi

    if [ $hostapd_instalado == false ];then
        clear
        echo "Hostapd no está instalado. ¿Desea instalarlo?"
        read resp

        if [[ $resp == "S" ]] || [[ $resp == "s" ]]; then

            clear

            echo "Instalando Hostapd"
            while true;do echo -n .;sleep 1;done &
            apt-get install -y -q -f hostapd > /dev/null;clear

            if [ $? != 0 ]; then
                clear
                echo "Instalación fallida"
                read -s
            else
                clear
                echo "Instalación correcta. Pulse una tecla"
                read -s
            fi
        fi
    fi

    if [ $dhcp_instalado == false ];then
        clear
        echo "DHCP no está instalado. ¿Desea instalarlo?"
        read resp

        if [[ $resp == "S" ]] || [[ $resp == "s" ]]; then

            clear

            echo "Instalando servidor isc-dhcp-server"
            while true;do echo -n .;sleep 1;done &
            apt-get install -y -q -f isc-dhcp-server > /dev/null;clear

            if [ $? != 0 ]; then
                clear
                echo "Instalación fallida"
                read -s
            else
                clear
                echo "Instalación correcta. Pulse una tecla"
                read -s
            fi
        fi
    fi
}

#Función que comprueba si Bash_HotSpot ha sido configurado en el equipo. En caso
# de no encontrar una BBDD, ofrece la instalación
comprueba_BBDD()
{

    local conexion
    local BBDD
    local resp

    clear
    #Realizamos la conexión y almacenamos la consulta en la variable
    conexion=`mysql -u $sql_usuario -p$sql_password -h $sql_host -e "show databases;"`
    #Almacenamos en la variable BBDD las bases de datos y la vaciamos si existe wifi
    BBDD=`echo $conexion | grep -v "wifi"`

    #Si queda vacía la variable es que existe
    if [ "$BBDD" == "" ];then
        echo -ne "Comprobando BBDD..."
        sleep 1
        echo -ne "OK"
        sleep 1
    else
        echo "WifiPlant necesita una base de datos para funcionar. ¿Desea instalarla?"
        read resp

        if [[ $resp == "S" ]] || [[ $resp == "s" ]]; then

            mysql -u $sql_usuario -p$sql_password -h $sql_host -e "create database wifiplant;"
            mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifi;create table usuarios(id_usu int not null auto_increment, usuario varchar(35), Nombre varchar(35), Apellido1 varchar(35), Apellido2 varchar(35), Clave varchar(200), sysuser boolean, primary key(id_usu));"

        else
            clear
            echo "Gracias por usar..."
            pon_dibujo
            exit 0
        fi
    fi
}

# Función que pone el encabezado en todos los menus
pon_encabezado()
{
    clear
    RAM_total=`free |head -2 |tail -1| awk '{print $2}'`
    RAM_total=`expr $RAM_total / 1024`
    RAM_ocupada=`free |head -2 |tail -1| awk '{print $3}'`
    RAM_ocupada=`expr $RAM_ocupada / 1024`
    disco_duro_total=`df -h | head -2 | tail -1| awk '{print $2}'`
    disco_duro_ocupado=`df -h | head -2 | tail -1| awk '{print $3}'`
    disco_duro_libre=`df -h | head -2 | tail -1| awk '{print $4}'`
    disco_duro_porc=`df -h | head -2 | tail -1| awk '{print $5}'`
    echo -e "\e[93m"

    echo -e "\e[37m"
    echo -e "\e[37mDistribución: $distribucion                                          \e[93m"
    echo -e "\e[37mkernel:       $kernel                               \e[0;36mWIFI\e[0;32mPlant \e[0;36m- La planta que controla tu red WIFI y te habla en Morse"
    echo -e "\e[0;37mCPU:          $CPU                           " #\e[93m__________________________"
    echo -e "\e[37mRAM:          $RAM_total (total) $RAM_ocupada (ocupada)"
    echo -e "\e[37mDisco duro:   $disco_duro_total (total) $disco_duro_ocupado ($disco_duro_porc) $disco_duro_libre (libre)"
    check_services

    id_pl=`mysql -u $sql_usuario -p$sql_password -h $sql_host -e "use wifiplant;select id_pl from plantas where activa=0;" | grep -v id_pl`
    temperatura=`mysql -u root -pPassword -h localhost -e "use wifiplant;select temperatura from planta_temperatura where id_pl='$id_pl' ORDER BY fecha desc limit 1;" | grep -v temperatura`
    humedad=`mysql -u root -pPassword -h localhost -e "use wifiplant;select humedad from planta_humedad where id_pl='$id_pl' ORDER BY fecha desc limit 1;" | grep -v humedad`

    if [[ $check_apache == true ]]; then
         echo -e "Apache:     \e[0;32m ON"
    else echo -e "Apache:     \e[0;31m OFF"
    fi

    if [[ $check_mysql == true ]]; then
        echo -e "\e[37mMySQL:      \e[0;32m ON"
    else echo -e "\e[37mMySQL:     \e[0;31m OFF"
    fi

    if [[ $check_dhcp == true ]]; then
        echo -e "\e[37mDHCP:       \e[0;32m ON                                                                              \e[0;36mTemperatura:    \e[0;32m $temperatura ºC"
    else echo -e "\e[37mDHCP:      \e[0;31m OFF"
    fi

    if [[ $check_freeradius == true ]]; then
        echo -e "\e[37mFreeradius: \e[0;32m ON                                                                              \e[0;36mHumedad:        \e[0;32m $humedad %"
    else echo -e "\e[37mFreeradius:\e[0;31m OFF"
    fi

    if [[ $check_hostapd == true ]]; then
        echo -e "\e[37mHostapd:    \e[0;32m ON"
    else echo -e "\e[37mHostapd:   \e[0;31m OFF"
    fi

    #echo -e "\e[0;36mTemperatura:    \e[0;32m $temperatura ºC"
    #echo -e "\e[0;36mHumedad:        \e[0;32m $humedad %"
}

menu_principal()
{
    pon_encabezado
    echo -e "\e[91m"
    echo_c "  1-Gestionar red                         2-Punto de acceso     "
    echo_c "                                                                "
    echo_c "  3-Freeradius                            4-Salir               "
    centra_cursor -2 25
    read -s -n 1 key

    case "$key" in

    1)  gest_red
    ;;
    2)  menu_punto_acceso
    ;;
    3) gest_freeradius
    ;;
    4)  clear
        #apaga_leds
        pon_msg "Gracias por usar..."
        #apaga_leds
        #is_running_check_sensors
        #apaga_leds
        clear
        pon_dibujo
        tput cnorm
        exit 0
    ;;
    h) pon_ayuda
       menu_principal
    ;;
    H) pon_ayuda
       menu_principal
    ;;
    *) clear
       pon_error;
       menu_principal
   ;;
    esac
}

pon_ayuda()
{
    pon_msg "Esto es la ayuda"
}

#Función para mostrar un error cuando se selecciona una opción no correcta
pon_error()
{
    clear
     echo -e "\e[0;36m"
     centra_cursor -2 25
     echo " Tienes que introducir una opción correcta. "
     sleep 2
}

# Función para mostrar mensajes personalizados
pon_msg()
{
    clear
    long=`echo ${#1}`
    long=`expr $long / 2`
    echo -e "\e[0;36m"
    centra_cursor -2 $long
    echo $1
    sleep 2

}

pon_dibujo()
{

    echo -e "\e[0;36m    __        _____ _____ ___  \e[0;32m  ____  _             _   "
    echo -e "\e[0;36m    \ \      / /_ _|  ___|_ _| \e[0;32m |  _ \| | __ _ _ __ | |_ "
    echo -e "\e[0;36m     \ \ /\ / / | || |_   | |  \e[0;32m | |_) | |/ _  | '_ \| __|"
    echo -e "\e[0;36m      \ V  V /  | ||  _|  | |  \e[0;32m |  __/| | (_| | | | | |_ "
    echo -e "\e[0;36m       \_/\_/  |___|_|   |___| \e[0;32m |_|   |_|\__,_|_| |_|\__|"

}

#Función para comrprobar si un servicio está activo
check_services()
{
    procesos_apache=`pgrep apache | wc -l`

    if [[ $procesos_apache != "0" ]]; then
        check_apache=true
    fi

    procesos_mysql=`pgrep mysql | wc -l`

    if [[ $procesos_mysql != "0" ]]; then
        check_mysql=true
    fi

    procesos_freeradius=`pgrep freeradius | wc -l`

    if [[ $procesos_freeradius != "0" ]]; then
        check_freeradius=true
    fi

    procesos_hostapd=`pgrep hostapd | wc -l`

    if [[ $procesos_hostapd != "0" ]]; then
        check_hostapd=true
    fi

     procesos_dhcp=`pgrep dhcp | wc -l`

    if [[ $procesos_dhcp != "0" ]]; then
        check_dhcp=true
    fi
}

#Funcion que comprueba si se ha introducido una ip válida
#http://unix.stackexchange.com/questions/111841/regular-expression-in-bash-to-validate-ip-address
validateIP()
{
    local ip=$1
    local stat=1
    if [[ $ip =~ ^[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}$ ]]; then
        OIFS=$IFS
        IFS='.'
        ip=($ip)
        IFS=$OIFS
        [[ ${ip[0]} -le 255 && ${ip[1]} -le 255 \
        && ${ip[2]} -le 255 && ${ip[3]} -le 255 ]]
        stat=$?
    fi
    return $stat
}

#http://stackoverflow.com/questions/21746863/netmask-validation-seems-not-working-using-regex-in-bash-script-while-ip-validat
validateMask()
{
    grep -E -q '^(254|252|248|240|224|192|128)\.0\.0\.0|255\.(254|252|248|240|224|192|128|0)\.0\.0|255\.255\.(254|252|248|240|224|192|128|0)\.0|255\.255\.255\.(254|252|248|240|224|192|128|0)' <<< "$1" && return $? || return $?
}


validate_number()
{
 es_numero='^-?[0-9]+([.][0-9]+)?$'
 if ! [[ $1 =~ $es_numero ]] ; then
   return $?
 else
     return $?
 fi
}

#Funcion que añade caracteres blanco a un string para igualarlos de tamaño
same_size_string()
{
    longitud_cadena=`expr length $cadena_a_ajustar`
    longitud_cadena=`expr $longitud_cadena + 0`
    #Corregimos la longitud de la cadena "usuario_logueado" para que sea siempre 10
    while [ $longitud_cadena -lt 9 ];
    do
        caracter_blanco=""
        cadena_a_ajustar=$cadena_a_ajustar" "$caracter_blanco
        longitud_cadena=`expr $longitud_cadena + 1`
    done

}

# Función para gestionar usuarios
gest_red()
{
    pon_encabezado
    echo -e "\e[91m"
    echo_c "  1-Elegir interfaces               2-Configurar IP   "
    echo_c "                                                      "
    echo_c "  3-Configurar DHCP                 4-Volver          "

    read -s -n 1 key

    case "$key" in

    1)  elige_interfaces
    ;;
    2)  configura_ip
    ;;
    3)  configura_dhcp
    ;;
    4)  menu_principal
    ;;
    *) clear
       pon_error;
       gest_red
   ;;
    esac
}

menu_punto_acceso()
{
    pon_encabezado
    echo -e "\e[91m"
    echo_c "  1-Configuración                   2-Monitorización  "
    echo_c "                                                      "
    echo_c "3-Reiniciar AP                    4-Volver            "

    read -s -n 1 resp
    #Comprobamos que se introduce un valor correcto

    case "$resp" in

    1)  configura_hostapd
    ;;
    2)  monitoriza_hostapd
    ;;
    3)  reinicia_punto_acceso
    ;;
    4)  menu_principal
    ;;
    *) clear
       pon_error;
       menu_punto_acceso
   ;;
    esac
}

configura_hostapd()
{
    declare -a  hostapd_conf
    local canal
    local SSID
    local radius_passwd
    local resp

    pon_encabezado
    echo -e "\e[91m"
    echo_c "Introduce el canal donde emitirá el punto de acceso"
    echo " "
    echo -e "\e[92m"
    centra_cursor -3 0
    read canal
    #El canal de emisión estará entre 1 y 13
    if [[ $canal -lt 1 ]] ||  [[ $canal -gt 13 ]]; then
        pon_msg "El canal tiene que ser un valor entre 1 y 13"
        configura_hostapd
    fi

    pon_encabezado
    echo -e "\e[91m"
    echo_c "Introduce el nombre SSID del punto de acceso"
    echo " "
    echo -e "\e[92m"
    centra_cursor -3 0
    read SSID

    pon_encabezado
    echo -e "\e[91m"
    echo_c "Introduce el password del Freeradius"
    echo " "
    centra_cursor -3 2
    echo -e -n "\e[92m"

    #Para el password usaremos asteriscos
    #http://stackoverflow.com/questions/1923435/how-do-i-echo-stars-when-reading-password-with-read
    unset radius_passwd
    while IFS= read -p "$prompt" -r -s -n 1 char
    do
        prompt=''
        # Enter - accept password
        if [[ $char == $'\0' ]] ; then
            break
        fi
        # Backspace
        if [[ $char == $'\177' ]] ; then
            prompt=$'\b \b'
            radius_passwd="${radius_passwd%?}"
        else
            prompt='*'
            radius_passwd+="$char"
        fi
    done

    #Consultamos si los datos que se han introducido son correctos
    pon_encabezado
    echo -e "\e[91m"
    echo_c "Va a modificar la configuración del punto de acceso. ¿Es correcta la nueva configuración? (S/N)"
    echo -e "\e[92m"
    echo_c "Nombre de la red: $SSID"
    echo_c "Canal de emisión: $canal"

    read -s -n 1 resp

    if [ $resp == "S" ] || [ $resp == "s" ]; then

        hostapd_conf[0]="interface=$int_WIFI"
        hostapd_conf[1]="driver=rtl871xdrv"
        hostapd_conf[2]="ssid=$SSID"
        hostapd_conf[3]="hw_mode=g"
        hostapd_conf[4]="channel=$canal"
        hostapd_conf[5]="macaddr_acl=0"
        hostapd_conf[6]="auth_algs=1"
        hostapd_conf[7]="ignore_broadcast_ssid=0"
        hostapd_conf[8]="wpa=2"
        hostapd_conf[9]="wme_enabled=1"
        hostapd_conf[10]="ieee80211n=1"
        hostapd_conf[11]="auth_algs=3"
        hostapd_conf[12]="ieee8021x=1"
        hostapd_conf[13]="eapol_version=2"
        hostapd_conf[14]="eap_message=hello"
        hostapd_conf[15]="eapol_key_index_workaround=1"
        hostapd_conf[16]="wpa_key_mgmt=WPA-EAP"
        hostapd_conf[17]="wpa_pairwise=TKIP CCMP"
        hostapd_conf[18]="rsn_pairwise=CCMP"
        hostapd_conf[19]="wpa_group_rekey=600"
        hostapd_conf[20]="wpa_gmk_rekey=86400"
        hostapd_conf[21]="eap_server=0"
        hostapd_conf[22]="own_ip_addr=127.0.0.1"
        hostapd_conf[23]="nas_identifier=a22AP"
        hostapd_conf[24]="auth_server_addr=127.0.0.1"
        hostapd_conf[25]="auth_server_port=1812"
        hostapd_conf[26]="auth_server_shared_secret=$radius_passwd"
        hostapd_conf[27]="acct_server_addr=127.0.0.1"
        hostapd_conf[28]="acct_server_port=1813"
        hostapd_conf[29]="acct_server_shared_secret=$radius_passwd"
        hostapd_conf[30]="ctrl_interface=/var/run/hostapd"

        rm /etc/hostapd/hostapd.conf

        for i in `seq 0 1 30`;
        do
            echo ${hostapd_conf[$i]} >>  /etc/hostapd/hostapd.conf
        done

        #Una vez configurado, aplicamos la configuración correspondiente en
        #freeradius. Pasamos las variables $SSID y $radius_passwd
        configura_freeradius_clients

        #Una vez finalizada la nueva configuración, reiniciamos hostapd
        reinicia_hostapd
        menu_punto_acceso
    else #Si los datos no son correctos, volvemos atrás
        menu_punto_acceso
    fi
}

connected()
{
    arp | grep $int_WIFI | grep C > connected.txt
    equipos_conectados=`cat connected.txt | wc -l`
    equipos_conectados=`expr $equipos_conectados - 1`

    for i in `seq 0 1 $equipos_conectados`;
    do
            linea=`expr $i + 1`
            ips_conect[$i]=`cat connected.txt  | grep $int_WIFI | grep C | awk {'print $1'} | head -$linea | tail -1`
            macs_conect[$i]=`cat connected.txt | grep $int_WIFI | grep C | awk {'print $3'} | head -$linea | tail -1`
            #Con la MAC preguntamos a Freeradius qué usuario logueado está asociado a esa MAC
            MAC_cortada=`echo ${macs_conect[$i]} | sed 's/:/-/g'`
            MAC_cortada=`echo $MAC_cortada | sed 's/.$//g'`
            MAC_cortada=`echo $MAC_cortada | sed 's/.$//g'`
            MAC_cortada=`echo $MAC_cortada | sed 's/.$//g'`
            MAC_cortada=`echo $MAC_cortada | tr [:lower:] [:upper:]`
            #usuario_logueado[$i]=`radwho -c | grep $MAC_cortada | head -1 | tail -1 | awk {'print $1'}`
            usuario_logueado[$i]=`mysql -u root -pPassword -h localhost -e "use radius;SELECT username FROM radacct WHERE callingstationid like '%$MAC_cortada%' limit 1" | grep -v username`
            if [[ ${usuario_logueado[$i]} == "" ]]; then
                usuario_logueado[$i]="Equipo $linea "
                else
                    #Corregimos la longitud de la cadena "usuario_logueado" para que sea siempre 10
                    cadena_a_ajustar=${usuario_logueado[$i]}
                    same_size_string #La función recoge el valor de "cadena_a_ajustar"
                    usuario_logueado[$i]=$cadena_a_ajustar
            fi

    done
}

monitoriza_hostapd()
{
    while true;
    do
        pon_encabezado
        echo -e -n "\e[92m"
        echo_c "Monitorizando...(Pulse una tecla)"
        echo -e "\e[0;36m"

        echo -e -n "\e[92m"
        echo_c "Usuario                         IP                           MAC      "
        echo -e "\e[0;36m"
        #arp | grep $int_WIFI | grep C | awk {'print $1 " " $3'}

        for i in `seq 0 1 $equipos_conectados`;
        do
            linea=`expr $i + 1`
            	
            echo_c " ${usuario_logueado[$i]}                  ${ips_conect[$i]}              ${macs_conect[$i]}"
        done

        connected
        sleep 3
        read -s -t 1 -n 1 resp

        if [ $? = 0 ] ; then

            #apaga_leds
            menu_punto_acceso
        else
          echo "Monitorizando..."
        fi
    done

}

reinicia_punto_acceso()
{
    reinicia_freeradius
    reinicia_hostapd
    menu_punto_acceso
}


reinicia_hostapd()
{
     if [[ $check_hostapd == true ]]; then
        killall hostapd >>  /dev/null
     fi
     pon_msg "Reiniciando el servicio hostapd"
     hostapd -B /etc/hostapd/hostapd.conf >>  /dev/null
}

reinicia_freeradius()
{
    if [[ $check_freeradius == true ]]; then
        killall freeradius >>  /dev/null
    fi
    pon_msg "Reiniciando el servicio Freeradius"
    freeradius >>  /dev/null
}

gest_freeradius()
{
    local key

    pon_encabezado
    echo -e "\e[91m"
    echo_c "  1-Añadir usuario               2-Borrar usuario   "
    echo_c "                                                    "
    echo_c " 3-Reiniciar servicio           4-Volver            "

    read -s -n 1 key

    case "$key" in

    1)  new_freeradius_users
    ;;
    2)  delete_free_radius_user
    ;;
    3)  reinicia_freeradius
        gest_freeradius
    ;;
    4) menu_principal
    ;;
    *) clear
       pon_error;
       gest_freeradius
   ;;
    esac
}

configura_freeradius_clients()
{
    declare -a  freeradius_clients_conf

    #El único cliente que se conectará al freeradius es el Punto de acceso local
    freeradius_clients_conf[0]="client 127.0.0.1 {"
    freeradius_clients_conf[1]="secret = $radius_passwd"
    freeradius_clients_conf[2]="shortname = $SSID"
    freeradius_clients_conf[3]="}"

    rm /etc/freeradius/clients.conf

    for i in `seq 0 1 3`;
    do
        echo ${freeradius_clients_conf[$i]} >>  /etc/freeradius/clients.conf
    done

    service freeradius restart >> /dev/null
}

new_freeradius_users()
{
    declare -a  freeradius_users_conf
    declare -a usuarios_agregados
    local new_user
    local comprueba_usuario
    local new_user_passwd

    #Soliciramos el usuarios del nuevo cliente
    pon_encabezado
    echo -e "\e[91m"
    echo_c "Introduce el nombre del nuevo usuario"
    echo " "
    centra_cursor -3 2
    echo -e -n "\e[92m"
    read new_user

    if [ -f /etc/freeradius/users ];then
        comprueba_usuario=`cat /etc/freeradius/users | grep $new_user | wc -l`

        #Si no existe el usuario no hay problema
        if [ $comprueba_usuario -ne 0 ];then
            pon_msg "El usuario $new_user ya está agregado"
            new_freeradius_users
        fi

    fi

    #Soliciramos el passwd del nuevo cliente
    pon_encabezado
    echo -e "\e[91m"
    echo_c "Introduce el password del usuario $new_user"
    echo " "
    centra_cursor -3 2
    echo -e -n "\e[92m"
    #Para el password usaremos asteriscos
    #http://stackoverflow.com/questions/1923435/how-do-i-echo-stars-when-reading-password-with-read
    unset new_user_passwd
    while IFS= read -p "$prompt" -r -s -n 1 char
    do
        prompt=''
        # Enter - accept password
        if [[ $char == $'\0' ]] ; then
            break
        fi
        # Backspace
        if [[ $char == $'\177' ]] ; then
            prompt=$'\b \b'
            new_user_passwd="${new_user_passwd%?}"
        else
            prompt='*'
            new_user_passwd+="$char"
        fi
    done

    #Consultamos si los datos que se han introducido son correctos
    pon_encabezado

    echo -e "\e[91m"
    echo_c "Va a agregar el usuario $new_user. ¿Desea continuar? (S/N)"

    read -n 1 resp

    if [ $resp == "S" ] || [ $resp == "s" ]; then
        #Añadimos el usuario y contraseña
        freeradius_users_conf[0]="$new_user Cleartext-Password := \"$new_user_passwd\""

        #Paramos el servicio y manipulamos el fichero
        if [[ $check_freeradius == true ]]; then
            killall freeradius >>  /dev/null
        fi
        for i in `seq 0 1 1`;
        do
            echo ${freeradius_users_conf[$i]} >> /etc/freeradius/users
        done
        limpia_freeradius_users >> /dev/null
        freeradius >> /dev/null
        pon_msg "Usuario agregado correctamente"
    else
        gest_freeradius
    fi

    gest_freeradius
}

delete_free_radius_user()
{
    declare -a usuarios_freeradius

    local num_lineas
    local linea
    local usuario
    local n_usuario
    local num_usuario
    local borrar
    local resp

    pon_encabezado
    #Comenzamos listando todos los usuarios
    num_lineas=`cat /etc/freeradius/users | wc -l`
    num_lineas=`expr $num_lineas - 1`

    echo -e  "\e[91m"
    echo_c "Elige el número del usuario a borrar"
    echo -e  "\e[92m"
    num_usuario=0
    for i in `seq 0 1 $num_lineas`;
    do
       linea=`expr $i + 1`
       usuario=`cat /etc/freeradius/users | head -$linea | tail -1 | awk '{ print $1 }'`
       cadena_a_ajustar=$usuario
       same_size_string
       usuarios_freeradius[$num_usuario]=$cadena_a_ajustar
       n_usuario=`expr $num_usuario + 1`
       echo_c "$n_usuario   ${usuarios_freeradius[$num_usuario]}"
       num_usuario=`expr $num_usuario + 1`
    done

    centra_cursor 0 0
    read -s borrar

    borrar=`expr $borrar - 1`
    pon_encabezado
    echo -e "\e[91m"
    echo_c "Has decidido borrar el usuario ${usuarios_freeradius[$borrar]}"
    echo_c "¿Deseas continuar? (S/N)"
    read -s -n 1 resp

    if [ $resp == "S" ] || [ $resp == "s" ]; then
        #Paramos el servicio y manipulamos el fichero
        if [[ $check_freeradius == true ]]; then
            killall freeradius >>  /dev/null
        fi

        #Borramos el usuario
        grep -v ${usuarios_freeradius[$borrar]} /etc/freeradius/users > temp && mv temp /etc/freeradius/users
        pon_msg "El usuario ha sido borrado"
        freeradius >> /dev/null
    else
        gest_freeradius
    fi

    gest_freeradius
}

#Elimina las lineas en blanco de /etc/freeradius/users
limpia_freeradius_users()
{
    local num_lineas
    local num_usuario
    local linea
    local usuario

    num_lineas=`cat /etc/freeradius/users | wc -l`
    num_usuario=0

    for i in `seq 0 1 $num_lineas`;
    do
       linea=`expr $i + 1`
       usuario=`cat /etc/freeradius/users | head -$linea | tail -1`

       if [[ -z $usuario ]]; then
           echo "" >> /dev/null
       else
            usuarios_freeradius[$num_usuario]=$usuario
            num_usuario=`expr $num_usuario + 1`
       fi
    done

    #Restamos uno porque el último sumado es vacío
    num_usuario=`expr $num_usuario - 1`

    # Si existe, /etc/freeradius/users  borramos el fichero
    if [ -f /etc/freeradius/users ]; then
        rm /etc/freeradius/users
    fi

    #Guardamos los usuarios linea a línea sin espacios en blanco
    for i in `seq 0 1 $num_usuario`;
    do
        echo ${usuarios_freeradius[$i]} >> /etc/freeradius/users
    done

    #sed -i "$num_lineasd" /etc/freeradius/users
}

#Con esta función expulsamos a un usuario concreto del hostapd
expulsa_usuario()
{

    local usuario_expulsado
    local MAC_usuario_expulsado
    local MAC_cortada

    usuario_expulsado=$1

    #Extraemos la MAC en formato 00-00-00-00-00-
    MAC_usuario_expulsado=`radwho -c | grep $usuario_expulsado | awk {'print $2'}`
    MAC_cortada=`echo $MAC_usuario_expulsado | sed 's/-/:/g'`
    MAC_cortada=`echo $MAC_cortada | tr [:upper:] [:lower:]`
    MAC_usuario_expulsado=`arp | grep $MAC_cortada | grep C | awk {'print $3'}`

    #Con la MAC, ya podemos expulsar "el caliente" al cliente del punto de acceso
    hostapd_cli deauthenticate  $MAC_usuario_expulsado >> /dev/null
}

configura_dhcp()
{

    local subnet
    local octeto_rango_inicio
    local octeto_rango_fin
    local rango_inicio
    local rango_fin
    local broadcast
    local resp

    #La puerta de enlace es la IP de la interfaz WIFI
    ip_int_WIFI=`ip addr show $int_WIFI | grep -v inet6 | grep 'inet' | sed 's/^[ \t]*//' | cut -f2 -d" " | cut -f1 -d"/"`

    #Obtenemos los octetos de la dirección IP
    validateIP $ip_int_WIFI
    OLD_IFS=$IFS
    IFS='.'
    set - $ip_int_WIFI
    octeto1=$1
    octeto2=$2
    octeto3=$3

    #Vovemos a recuperar los puntos en las cadenas
    IFS=''
    OLD_IFS=''

    #Calculamos la subnet (Máscara 255.255.255.0)
    subnet=$octeto1.$octeto2.$octeto3.0

    #Preguntamos la ip de origen del rango DHCP
    pon_encabezado
    echo -e "\e[91m"
    echo_c "Elige la ip de inicio del pool DHCP para la subred $subnet (último octeto)"
    echo " "
    echo -e "\e[92m"
    centra_cursor -3 0
    read octeto_rango_inicio

    #Primero comprobamos si hemos introducido un número
    validate_number $octeto_rango_inicio
    while [[ $? -ne 1 ]];
    do
        pon_msg "Has introducido un carácter"
        configura_dhcp
    done

    #Mientras no se de un rango correcto, preguntamos
    while [[ $octeto_rango_inicio -lt 2 ]] || [[ $octeto_rango_inicio -gt 253 ]];do
        pon_msg "Tienes que introducir un rango correcto"
        pon_encabezado
        echo -e "\e[91m"
        echo_c "Elige la ip de inicio del pool DHCP para la subred $subnet (último octeto)"
        echo " "
        echo -e "\e[92m"
        centra_cursor -3 0
        read octeto_rango_inicio
    done

    rango_inicio=$octeto1.$octeto2.$octeto3.$octeto_rango_inicio

    #Preguntamos la ip final del rango DHCP
    pon_encabezado
    echo -e "\e[91m"
    echo_c "Elige la ip final del pool DHCP para la subred $subnet (último octeto)"
    echo " "
    echo -e "\e[92m"
    centra_cursor -3 0
    read octeto_rango_fin

    #Comprobamos que introducimos un numero
    validate_number $octeto_rango_fin
    while [[ $? -ne 1 ]];
    do
        pon_msg "Has introducido un carácter"
        pon_encabezado
        echo -e "\e[91m"
        echo_c "Elige la ip final del pool DHCP para la subred $subnet (último octeto)"
        echo " "
        echo -e "\e[92m"
        centra_cursor -3 0
        read octeto_rango_fin
        validate_number $octeto_rango_fin
    done

     #Mientras no se de un rango correcto, preguntamos. El rango final no puede ser menor que
     #el inicial.
    while [[ $octeto_rango_fin -lt $octeto_rango_inicio ]] || [[ $octeto_rango_fin -gt 254 ]];do
        pon_msg "Tienes que introducir un rango correcto"
        pon_encabezado
        echo -e "\e[91m"
        echo_c "Elige la ip final del pool DHCP para la subred $subnet (último octeto)"
        echo " "
        echo -e "\e[92m"
        centra_cursor -3 0
        read octeto_rango_fin
    done
    rango_fin=$octeto1.$octeto2.$octeto3.$octeto_rango_fin

    #Calculamos la ip de broadcast
    broadcast=$octeto1.$octeto2.$octeto3.255
    pon_encabezado
    echo -e "\e[91m"
    echo_c "Va a cambiar la configuración DHCP con los siguientes datos: ¿Desea continuar? (S/N)"
    echo -e "\e[92m"
    echo_c "El rango inicia en:   $rango_inicio"
    echo_c "El rango finaliza en: $rango_fin "

    read -n 1 resp

    if [ $resp == "S" ] || [ $resp == "s" ]; then

        declare -a  dhcp_conf

        if [ -f /etc/dhcp/dhcpd.conf ]; then
           rm /etc/dhcp/dhcpd.conf
        fi

        dhcp_conf[0]="authoritative;"
        echo ${dhcp_conf[0]} >> /etc/dhcp/dhcpd.conf
        dhcp_conf[1]="ddns-update-style none;"
        echo ${dhcp_conf[1]} >> /etc/dhcp/dhcpd.conf
        dhcp_conf[2]="default-lease-time 600;"
        echo ${dhcp_conf[2]} >> /etc/dhcp/dhcpd.conf
        dhcp_conf[3]="max-lease-time 7200;"
        echo ${dhcp_conf[3]} >> /etc/dhcp/dhcpd.conf
        dhcp_conf[4]="log-facility local7;"
        echo ${dhcp_conf[4]} >> /etc/dhcp/dhcpd.conf
        dhcp_conf[5]="subnet $subnet netmask 255.255.255.0 {"
        echo ${dhcp_conf[5]} >> /etc/dhcp/dhcpd.conf
        dhcp_conf[6]="range $rango_inicio $rango_fin;"
        echo ${dhcp_conf[6]} >> /etc/dhcp/dhcpd.conf
        dhcp_conf[7]="option broadcast-address $broadcast;"
        echo ${dhcp_conf[7]} >> /etc/dhcp/dhcpd.conf
        dhcp_conf[8]="option routers $ip_int_WIFI;"
        echo ${dhcp_conf[8]} >> /etc/dhcp/dhcpd.conf
        dhcp_conf[9]="default-lease-time 600;"
        echo ${dhcp_conf[9]} >> /etc/dhcp/dhcpd.conf
        dhcp_conf[10]="max-lease-time 7200;"
        echo ${dhcp_conf[10]} >> /etc/dhcp/dhcpd.conf
        dhcp_conf[11]="option domain-name \"local\";"
        echo ${dhcp_conf[11]} >> /etc/dhcp/dhcpd.conf
        dhcp_conf[12]="option domain-name-servers 8.8.8.8, 8.8.4.4;"
        echo ${dhcp_conf[12]} >> /etc/dhcp/dhcpd.conf
        dhcp_conf[13]="interface $int_WIFI;"
        echo ${dhcp_conf[13]} >> /etc/dhcp/dhcpd.conf
        dhcp_conf[14]="}"
        echo ${dhcp_conf[14]} >> /etc/dhcp/dhcpd.conf

        service isc-dhcp-server restart >> /dev/null
        gest_red
    else
        gest_red
    fi
}

configura_red()
{
    declare -a  red_conf
    declare -a int_cable_conf
    declare -a int_WIFI_conf

    red_conf[0]="auto lo"
    red_conf[1]="iface lo inet loopback"
    red_conf[2]="source /etc/network/$int_cable.txt"
    red_conf[3]="source /etc/network/$int_WIFI.txt"

    #Comprobamos los valores que nos han pasado. Si es DHCP aplicamos
    if [[ $1 == "DHCP" ]]; then

        int_cable_conf[0]="auto $int_cable"
        int_cable_conf[1]="iface $int_cable inet dhcp"

        if [ -f "/etc/network/interfaces" ]; then
            rm /etc/network/interfaces
        fi

        for i in `seq 0 1 3`;
        do
            echo ${red_conf[$i]} >>  /etc/network/interfaces
        done

        #Si existe el fichero correspondiente a la interfaz, lo borramos
        if [ -f "/etc/network/$int_cable.txt" ]; then
            rm /etc/network/$int_cable.txt
        fi

        for i in `seq 0 1 1`;
        do
            echo ${int_cable_conf[$i]} >>  /etc/network/$int_cable.txt
        done
        gest_red
    fi

    #En caso de que estemos configurando la interfaz de cable con IP fija
    if [[ $1 == $int_cable ]]; then

        int_cable_conf[0]="auto $int_cable"
        int_cable_conf[1]="iface $int_cable inet static"
        int_cable_conf[2]="address $direccion_ip"
        int_cable_conf[3]="netmask $mascara"
        int_cable_conf[4]="gateway $puerta_enlace"

        if [ -f "/etc/network/interfaces" ]; then
            rm /etc/network/interfaces
        fi

        for i in `seq 0 1 3`;
        do
            echo ${red_conf[$i]} >>  /etc/network/interfaces
        done

        #Si existe el fichero correspondiente a la interfaz, lo borramos
        if [ -f "/etc/network/$int_cable.txt" ]; then
            rm /etc/network/$int_cable.txt
        fi

        for i in `seq 0 1 4`;
        do
            echo ${int_cable_conf[$i]} >>  /etc/network/$int_cable.txt
        done
        gest_red
    fi

    #En caso de que estemos configurando la interfaz de WIFI, sólo puede ser con IP fija
    if [[ $1 == $int_WIFI ]]; then

        int_WIFI_conf[0]="auto $int_WIFI"
        int_WIFI_conf[1]="iface $int_WIFI inet static"
        int_WIFI_conf[2]="address $direccion_ip"
        int_WIFI_conf[3]="netmask $mascara"

        if [ -f "/etc/network/interfaces" ]; then
            rm /etc/network/interfaces
        fi

        for i in `seq 0 1 3`;
        do
            echo ${red_conf[$i]} >>  /etc/network/interfaces
        done

        #Si existe el fichero correspondiente a la interfaz, lo borramos
        if [ -f "/etc/network/$int_WIFI.txt" ]; then
            rm /etc/network/$int_WIFI.txt
        fi

        for i in `seq 0 1 3`;
        do
            echo ${int_WIFI_conf[$i]} >>  /etc/network/$int_WIFI.txt
        done
       gest_red
    fi

    /etc/init.d/networking restart >> /dev/null
}

comprueba_interfaces()
{
    #Comprobamos si tenemos activas las interfaces cable y wifi
    int_cable=`ip addr show | grep "state UP" | awk '{print $2}' | cut -f1 -d":" | grep eth`
    int_WIFI=`ip addr show | grep "state UP" | awk '{print $2}' | cut -f1 -d":" | grep wlan`

    #Si no tenemos activa alguna, las configuramos y volvemos a probar
    if [[ -z $int_cable ]] || [[ -z $int_WIFI ]]; then
        msg_interfaces
        elige_interfaz_cable
        elige_interfaz_wifi
    fi
}

msg_interfaces()
{

    local resp

    pon_encabezado
    echo -e "\e[91m"
    echo_c "Actualmente no hay 2 interfaces activas necesarias para configurar el HotSpot (una LAN/WAN y otra WIFI)"
    echo " "
    echo_c "Las interfaces activas son: $int_cable $int_WIFI"
    echo " "
    sleep 2
    echo_c "Pulsa una tecla para continuar..."
    read -s -n 1 resp

}

elige_interfaces()
{
    elige_interfaz_cable
    elige_interfaz_wifi
    gest_red
}

elige_interfaz_cable()
{
     #Decimos las interfaces que tenemos activas y ofrecemos la posibilidad de cambiar

    declare -a interfaz_cable
    local num_interfaz_cable
    local valor_max_indice
    local linea
    local interfaz_cable_elegida
    local elegida

    pon_encabezado
    echo -e "\e[91m"
    echo_c "¿Cuál es la interfaz conectada a la LAN/WAN?"
    echo -e "\e[92m"

    num_interfaz_cable=`ip link show|grep ^[0-9]| grep -v lo|cut -f2 -d":"|sed 's/^[ \t]*//' |grep eth |wc -l`
    valor_max_indice=$num_interfaz_cable
    num_interfaz_cable=`expr $num_interfaz_cable - 1`

    for i in `seq 0 1 $num_interfaz_cable`;
    do
       linea=`expr $i + 1`
       interfaz_cable[$i]=`ip link show|grep ^[0-9]| grep -v lo|cut -f2 -d":"|sed 's/^[ \t]*//' |grep eth |head -$linea|tail -1`
       echo_c "$linea ${interfaz_cable[$i]}"
    done

   interfaz_cable_elegida=false
   while [ $interfaz_cable_elegida == false ]; do
        read -s -n 1 num_interfaz_cable

        if [[ $num_interfaz_cable -lt 1 ]] || [[ $num_interfaz_cable -gt $valor_max_indice ]]; then
            interfaz_cable_elegida=false
            pon_msg "Tienes que elegir una opción correcta"
            elige_interfaz_cable
            num_interfaz_cable=1
        else
            interfaz_cable_elegida=true
        fi
    done

    elegida=`expr $num_interfaz_cable - 1`
    int_cable=${interfaz_cable[$elegida]}
}

elige_interfaz_wifi()
{

    declare -a interfaz_wifi

    local num_interfaz_WIFI
    local linea
    local interfaz_wifi_elegida
    local elegida

    #Hacemoslos mismo con la tarjeta WIFI
    pon_encabezado
    echo -e "\e[91m"
    echo_c "¿Cuál es la interfaz que actuará como punto de acceso?"
    echo -e "\e[92m"

    num_interfaz_WIFI=`ip link show|grep ^[0-9]| grep -v lo|cut -f2 -d":"|sed 's/^[ \t]*//' |grep wlan |wc -l`

    #Si no tenemos ninguna interfaz WIFI en el equipo, no podemos continuar
    if [[ $num_interfaz_WIFI == 0 ]]; then
        pon_msg "No se ha detectado ninguna interfaz WIFI en el equipo. No se puede continuar."
        clear
        pon_dibujo
        exit 0
    fi

    valor_max_indice=$num_interfaz_WIFI
    num_interfaz_WIFI=`expr $num_interfaz_WIFI - 1`

    for i in `seq 0 1 $num_interfaz_WIFI`;
    do
       linea=`expr $i + 1`
       interfaz_wifi[$i]=`ip link show|grep ^[0-9]| grep -v lo|cut -f2 -d":"|sed 's/^[ \t]*//' |grep wlan |head -$linea|tail -1`
       echo_c "$linea ${interfaz_wifi[$i]}"
    done

    interfaz_wifi_elegida=false
    while [ $interfaz_wifi_elegida == false ]; do
        read -s -n 1 num_interfaz_wifi

        if [[ $num_interfaz_wifi -lt 1 ]] || [[ $num_interfaz_wifi -gt $valor_max_indice ]]; then
            interfaz_wifi_elegida=false
            pon_msg "Tienes que elegir una opción correcta"
            elige_interfaz_wifi
            num_interfaz_wifi=1
        else
            interfaz_wifi_elegida=true
        fi
    done

    elegida=`expr $num_interfaz_wifi - 1`
    int_WIFI=${interfaz_wifi[$elegida]}
}

configura_ip()
{

    local resp
    local tipo_conf

    pon_encabezado
    echo -e "\e[91m"
    echo_c "Elige la interfaz sobre la que quieres cambiar la configuración"
    echo -e "\e[92m"
    echo_c "1-$int_cable  "
    echo_c " 2-$int_WIFI  "
    centra_cursor 0 0
    read -s -n 1 resp

    #Solo podemos elegir la configuración en la interfaz cable o WIFI
    if [[ $resp == "1" ]] || [[ $resp == "2" ]]; then

       #Si elegimos la interfaz de cable, podemos configurarla por DHCP o estática
       if [[ $resp == "1" ]]; then
            pon_encabezado
            echo -e "\e[91m"
            echo_c "Elige el tipo de configuración"
            echo -e "\e[92m"
            echo_c " 1-IP estática"
            echo_c "2-DHCP        "
            centra_cursor 0 0
            read -s -n 1 tipo_conf

            #Si la configuración es DHCP, la aplicamos
             if [[ $tipo_conf == "2" ]]; then
                configuracion="DHCP"
                configura_red $configuracion
                gest_red
             fi

        #Si no elegimos una opción correcta, volvemos a empezar
        else
            if [[ $resp != "2" ]]; then
                pon_msg "Tienes que elegir una opción correcta"
                configura_ip
            fi
       fi

       #Si no es DHCP, leemos la dirección IP y comprobamos que es correcta
       pon_encabezado
       echo -e "\e[91m"
       echo_c "Introduce la dirección IP"
       echo -e "\e[92m"
       centra_cursor -4 0
       read direccion_ip
       validateIP $direccion_ip
       while [[ $? -ne 0 ]];do
         pon_encabezado
         echo -e "\e[91m"
         echo_c "Introduce la dirección IP"
         echo -e "\e[92m"
         centra_cursor -4 0
         read direccion_ip
         validateIP $direccion_ip
       done

       #Leemos la máscara y comprobamos que es correcta
       pon_encabezado
       echo -e "\e[91m"
       echo_c "Introduce la máscara de red"
       echo -e "\e[92m"
       centra_cursor -4 0
       read mascara
       validateMask $mascara
       while [[ $? -ne 0 ]]; do
         pon_encabezado
         echo -e "\e[91m"
         echo_c "Introduce la máscara de red"
         echo -e "\e[92m"
         centra_cursor -4 0
         read mascara
         validateMask $mascara
       done

       #Si configuramos la interfaz de cable, seleccionamos la puerta de enlace
       if [ $resp == "1" ]; then
          #Leemos la dirección IP y comprobamos que es correcta
           pon_encabezado
           echo -e "\e[91m"
           echo_c "Introduce la puerta de enlace"
           echo -e "\e[92m"
           centra_cursor -4 0
           read puerta_enlace
           validateIP $puerta_enlace
           while [[ $? -ne 0 ]];do
             pon_encabezado
             echo -e "\e[91m"
             echo_c "Introduce la puerta de enlace"
             echo -e "\e[92m"
             centra_cursor -4 0
             read puerta_enlace
             validateIP $puerta_enlace
           done

           #Si elegimos la interfaz de cable, aplicamos la configuración
           configura_red $int_cable

       #Si hemos elegido la interfaz WIFI, no pondremos puerta de enlace
       else
           configura_red $int_WIFI
       fi

    else
        pon_msg "Tienes que elegir una opción correcta."
        configura_ip
    fi
}


# Función para comprobar si ya está lanzado el demonio check_sensors
is_running_check_sensors()
{
    local proceso
    local num_procesos

    #Comprobamos si existe el proceso. En ese caso, lo paramos
    num_procesos=`ps aux | grep check_sensors | grep -v grep | awk {'print $2'} | wc -l`

    if [ $num_procesos -gt 0 ]; then
        proceso=`ps aux | grep check_sensors | grep -v grep | awk {'print $2'}`
        kill -9 $proceso
    fi
}

# Función para leer la temperatura y humedad y almacenarla en la BBDD cada 60 segundos
check_sensors2()
{
    bash check_sensors.sh
}

# Cada vez que modifiquemos, parámetros, irán incluidos en un script de inicio
script_inicio()
{
    #Comprobamos si existe el script
    if [ -f /etc/init.d/hotspot.sh ]; then
        rm /etc/init.d/hotspot.sh
    #else
     #   touch /etc/init.d/rc.hotspot
    fi
    #echo 1 > /proc/sys/net/ipv4/ip_forward
    #iptables -t nat -A POSTROUTING -o $int_cable -j MASQUERADE
}

# -----------------Comienza el Script------------------

#La administración de servicios requiere permisos de root. Si no los tenemos,
# debemos ejecutar el script nuevamente con permisos
soy_root

# Primero comprobamos los servicios instalados
#instala_servicios

# Comprobamos si ya disponemos de BBDD y configuración en el equipo
#comprueba_BBDD

# Si está corriendo la función que chequea los sensores, la paramos
#is_running_check_sensors

# Lanzamos el demonio con los sensores
#check_sensors2&

#Lanzamos el demonio que localiza los equipos arp
#connected

# Comprobamos las interfaces activas
comprueba_interfaces

#Abrimos los puertos y lanzamos los servicios
#script_inicio

# Presentamos el menú principal
menu_principal

